

model Test3PhaseSystemsSwitch 
  constant Real pi=Modelica.Constants.pi;
  parameter Real shift=0.4;
  parameter Real t0=2;
  Real i_abc[3]={I1.i,I2.i,I3.i};
  Real i_dq0[3];
  Real power;
protected 
  Real theta;
  Real P[3,3];
  Real u_abc[3]={Sleft1.v,Sleft2.v,Sleft3.v};
  Real u_dq0[3];
public 
  Modelica.Electrical.Analog.Basic.Resistor Resistor1(R=.5) 
    annotation (extent=[-8,40; 12,60]);
  Modelica.Electrical.Analog.Basic.Inductor I1 
                                              annotation (extent=[-36,40; -16,
        60]);
  Modelica.Electrical.Analog.Basic.Resistor Resistor2(R=.5) 
    annotation (extent=[-6,0; 14,20]);
  Modelica.Electrical.Analog.Basic.Inductor I2 
                                              annotation (extent=[-36,0; -16,20]);
  Modelica.Electrical.Analog.Basic.Resistor Resistor3(R=.5) 
    annotation (extent=[-4,-40; 16,-20]);
  Modelica.Electrical.Analog.Basic.Inductor I3 
    annotation (extent=[-32,-40; -12,-20]);
  annotation (Diagram, uses(Modelica(version="1.6")));
  Modelica.Electrical.Analog.Sources.SineVoltage Sleft1 
    annotation (extent=[-60,40; -40,60], rotation=0);
  Modelica.Electrical.Analog.Sources.SineVoltage Sleft3(phase=4*pi/3) 
    annotation (extent=[-60,-40; -40,-20], rotation=0);
  Modelica.Electrical.Analog.Sources.SineVoltage Sleft2(phase=2*pi/3) 
    annotation (extent=[-60,0; -40,20], rotation=0);
  Modelica.Electrical.Analog.Basic.Ground Ground1 
    annotation (extent=[70,-84; 90,-64]);
  Modelica.Electrical.Analog.Sources.SineVoltage Sright1(phase=shift) 
    annotation (extent=[60,40; 80,60], rotation=0);
  Modelica.Electrical.Analog.Sources.SineVoltage Sright2(phase=2*pi/3 + shift) 
               annotation (extent=[60,0; 80,20], rotation=0);
  Modelica.Electrical.Analog.Sources.SineVoltage Sright3(phase=4*pi/3 + shift) 
               annotation (extent=[60,-40; 80,-20], rotation=0);
  IdealSwitchDummy S1(t0=t0) 
                   annotation (extent=[26,40; 46,60]);
  IdealSwitchDummy S2(t0=t0) 
                   annotation (extent=[26,0; 46,20]);
  IdealSwitchDummy S3(t0=t0) 
                   annotation (extent=[28,-40; 48,-20]);
initial equation 
  der(i_dq0)={0,0,0};
equation 
  theta = 2*pi*time;
  P = sqrt(2)/sqrt(3)*
    [sin(theta), sin(theta+2*pi/3), sin(theta+4*pi/3);
     cos(theta), cos(theta+2*pi/3), cos(theta+4*pi/3);
     1/sqrt(2), 1/sqrt(2), 1/sqrt(2)];
  u_dq0 = P*u_abc;
  i_dq0 = P*i_abc;
  power = u_dq0*i_dq0;
  connect(I2.n, Resistor2.p) 
    annotation (points=[-16,10; -6,10],
                                      style(color=3, rgbcolor={0,0,255}));
  connect(I1.n, Resistor1.p) 
    annotation (points=[-16,50; -8,50],
                                      style(color=3, rgbcolor={0,0,255}));
  connect(I3.n, Resistor3.p) 
    annotation (points=[-12,-30; -4,-30],
                                        style(color=3, rgbcolor={0,0,255}));
  connect(I1.p, Sleft1.n) 
    annotation (points=[-36,50; -40,50], style(color=3, rgbcolor={0,0,255}));
  connect(Sleft3.n, I3.p) 
    annotation (points=[-40,-30; -32,-30], style(color=3, rgbcolor={0,0,255}));
  connect(Sleft2.n, I2.p) 
    annotation (points=[-40,10; -36,10], style(color=3, rgbcolor={0,0,255}));
  connect(Sleft1.p, Sleft2.p) 
    annotation (points=[-60,50; -60,10], style(color=3, rgbcolor={0,0,255}));
  connect(Sleft2.p, Sleft3.p) 
    annotation (points=[-60,10; -60,-30], style(color=3, rgbcolor={0,0,255}));
  connect(Sleft3.p, Ground1.p)       annotation (points=[-60,-30; -60,-64; 80,
        -64], style(color=3, rgbcolor={0,0,255}));
  connect(Sright1.n, Sright2.n) 
    annotation (points=[80,50; 80,10], style(color=3, rgbcolor={0,0,255}));
  connect(Sright2.n, Sright3.n) 
    annotation (points=[80,10; 80,-30], style(color=3, rgbcolor={0,0,255}));
  connect(Sright3.n, Ground1.p) 
    annotation (points=[80,-30; 80,-64], style(color=3, rgbcolor={0,0,255}));
  connect(Resistor1.n, S1.p) 
    annotation (points=[12,50; 26,50], style(color=3, rgbcolor={0,0,255}));
  connect(S1.n, Sright1.p) 
    annotation (points=[46,50; 60,50], style(color=3, rgbcolor={0,0,255}));
  connect(Resistor2.n, S2.p) 
    annotation (points=[14,10; 26,10], style(color=3, rgbcolor={0,0,255}));
  connect(S2.n, Sright2.p) 
    annotation (points=[46,10; 60,10], style(color=3, rgbcolor={0,0,255}));
  connect(Resistor3.n, S3.p) 
    annotation (points=[16,-30; 28,-30], style(color=3, rgbcolor={0,0,255}));
  connect(S3.n, Sright3.p) 
    annotation (points=[48,-30; 60,-30], style(color=3, rgbcolor={0,0,255}));
end Test3PhaseSystemsSwitch;
