package Architectures 
  partial model AutomaticArchitecture 
    "Architecture for automatic transmissions" 
    extends VehicleSystems.Interfaces.Subsystems.Transmission;
    Interfaces.Gearbox gearbox annotation (extent=[0,-20; 40,20]);
    Modelica.Mechanics.Rotational.Interfaces.Compliant Compliant1 
      annotation (extent=[-60,-10; -40,10]);
    Modelica.Mechanics.Rotational.Clutch Clutch1 
      annotation (extent=[-60,30; -40,50]);
    annotation (Diagram);
  equation 
    connect(Clutch1.flange_a, input_shaft) annotation (points=[-60,40; -80,40;
          -80,0; -100,0], style(color=0, rgbcolor={0,0,0}));
    connect(input_shaft, Compliant1.flange_a) 
      annotation (points=[-100,0; -60,0], style(color=0, rgbcolor={0,0,0}));
    connect(Clutch1.flange_b, gearbox.turbine_shaft) annotation (points=[-40,40;
          -20,40; -20,0; 0,0], style(color=0, rgbcolor={0,0,0}));
    connect(Compliant1.flange_b, gearbox.turbine_shaft) 
      annotation (points=[-40,0; 0,0], style(color=0, rgbcolor={0,0,0}));
    connect(gearbox.transmission_mounts, transmission_mounts) annotation (
        points=[20,-20; 20,-60; 0,-60; 0,-100], style(color=3, rgbcolor={0,0,
            255}));
    connect(gearbox.power, power) annotation (points=[40,-20; 40,-100; 100,-100],
        style(color=3, rgbcolor={0,0,255}));
    connect(gearbox.driver_bus, driver_bus) annotation (points=[8,20; 8,70; -60,
          70; -60,100], style(color=3, rgbcolor={0,0,255}));
    connect(transmission_bus, gearbox.transmission_bus) annotation (points=[0,
          100; 20,100; 20,20], style(color=3, rgbcolor={0,0,255}));
    connect(gearbox.output_shaft, output_shaft) 
      annotation (points=[40,0; 100,0], style(color=0, rgbcolor={0,0,0}));
  end AutomaticArchitecture;
  
  partial model ManualArchitecture "Architecture for manual transmissions" 
    extends VehicleSystems.Interfaces.Subsystems.Transmission;
  end ManualArchitecture;
  
  partial model ClutchlessArchitecture 
    "Architecture for a simple clutchless model" 
    extends VehicleSystems.Interfaces.Subsystems.Transmission;
    replaceable Interfaces.Gearbox gearbox annotation (extent=[-40,-40; 40,40],
        choicesAllMatching);
    annotation (Diagram);
  equation 
    connect(gearbox.turbine_shaft, input_shaft) 
      annotation (points=[-40,0; -100,0], style(color=0, rgbcolor={0,0,0}));
    connect(gearbox.driver_bus, driver_bus) annotation (points=[-24,40; -24,60;
          -60,60; -60,100], style(
        color=0,
        rgbcolor={0,0,0},
        pattern=3,
        thickness=2));
    connect(gearbox.transmission_bus, transmission_bus) annotation (points=[0,40;
          0,100], style(
        color=0,
        rgbcolor={0,0,0},
        pattern=3,
        thickness=2));
    connect(gearbox.output_shaft, output_shaft) 
      annotation (points=[40,0; 100,0], style(color=0, rgbcolor={0,0,0}));
    connect(gearbox.power, power) annotation (points=[40,-40; 40,-60; 100,-60;
          100,-100], style(color=1, rgbcolor={255,0,0}));
    connect(gearbox.transmission_mounts, transmission_mounts) 
      annotation (points=[0,-40; 0,-100], style(color=0, rgbcolor={0,0,0}));
  end ClutchlessArchitecture;
end Architectures;
