model ClutchlessStepRatioTransmission "A clutchless step ratio transmission" 
  parameter Real ratios[:]={8,4,2} "Gear ratios (1st-nth gear)";
  extends Gearboxes.BaseClasses.VariableRatioTransmission(redeclare connector 
      TransmissionBus = GearNumberBus);
protected 
  connector GearNumberBus 
    extends VehicleSystems.Icons.Bus;
    input Integer requested_gear_number;
  end GearNumberBus;
  
  function Ratio 
    input Integer i;
    input Real ratios[:];
    output Real R;
  algorithm 
    assert(i<=size(ratios,1), "Gear number requested was too high for this transmission");
    assert(i>=-1, "Negative gear numbers less than -1 are invalid");
    if i>=1 and i<=size(ratios,1) then
      R := ratios[i];
    elseif i==0 then
      R := 0;
    else
      R := -ratios[1];
    end if;
  end Ratio;
equation 
  shift = change(transmission_bus.requested_gear_number) or initial();
  next_ratio =  Ratio(transmission_bus.requested_gear_number,ratios);
end ClutchlessStepRatioTransmission;
