package Controllers 
  model GearFromDriver "Gear selected by driver model" 
    extends VehicleSystems.Interfaces.Subsystems.TransmissionController(
                                                             redeclare 
        connector TransmissionBus = 
          GearNumberBus, redeclare connector DriverBus=LocalDriverBus);
  protected 
    connector GearNumberBus 
      extends VehicleSystems.Icons.Bus;
      output Integer requested_gear_number;
    end GearNumberBus;
    
    connector LocalDriverBus 
      extends VehicleSystems.Icons.Bus;
      Modelica.Blocks.Interfaces.IntegerSignal requested_gear;
    end LocalDriverBus;
  equation 
    transmission_bus.requested_gear_number =  driver_bus.requested_gear;
  end GearFromDriver;

  model ShiftSchedule "Gear selected by shift schedule" 
    extends VehicleSystems.Interfaces.Subsystems.TransmissionController(
                                                             redeclare 
        connector TransmissionBus = 
          GearNumberBus, redeclare connector DriverBus = 
          LocalDriverBus);
    parameter Types.KPH upshift[:] = {25, 50, 70, 100};
    parameter Types.KPH downshift[:] = {20, 40, 60, 90};
  protected 
    connector LocalDriverBus 
      extends VehicleSystems.Icons.Bus;
      Modelica.Blocks.Interfaces.RealSignal vehicle_speed(
                                                        redeclare type 
          SignalType = 
            Types.KPH);
    end LocalDriverBus;
    parameter Integer speeds = size(upshift,1)+1;
    Integer current_gear;
    Modelica.Blocks.Interfaces.RealInput vehicle_speed(redeclare type 
        SignalType =                                                             Types.KPH);
    Types.KPH next_upshift;
    Types.KPH next_downshift;
    connector GearNumberBus 
      extends VehicleSystems.Icons.Bus;
      output Integer requested_gear_number;
    end GearNumberBus;
  initial algorithm 
    assert(size(upshift,1)==size(downshift,1), "Upshift and downshift schedules must be the same size");
    current_gear:=1;
    //while (current_gear<speeds and vehicle_speed>upshift[current_gear]) loop
    // current_gear := current_gear + 1;
    //end while;
    next_upshift := if current_gear<speeds then upshift[current_gear] else Modelica.Constants.inf;
    next_downshift := if current_gear>1 then downshift[current_gear-1] else -Modelica.Constants.inf;
  algorithm 
    when vehicle_speed>next_upshift then
      current_gear := current_gear+1;
      next_upshift := if current_gear<speeds then upshift[current_gear] else Modelica.Constants.inf;
      next_downshift := if current_gear>1 then downshift[current_gear-1] else -Modelica.Constants.inf;
    end when;
    when vehicle_speed<next_downshift then
      current_gear := current_gear-1;
      next_upshift := if current_gear<speeds then upshift[current_gear] else Modelica.Constants.inf;
      next_downshift := if current_gear>1 then downshift[current_gear-1] else -Modelica.Constants.inf;
    end when;
  equation 
    transmission_bus.requested_gear_number = current_gear;
    connect(vehicle_speed,driver_bus.vehicle_speed);
  end ShiftSchedule;
end Controllers;
