partial model Driver "Interfaces to define driver-vehicle interactions" 
  
  extends VehicleSystems.Icons.Driver;
  extends VehicleSystems.Interfaces.Subsystems.Driver;
  annotation (
    Documentation(info="<html>
<p>
For the purposes of use in an expandable modular vehicle model, the Driver is defined as a subsystem that applies <b>non-electrical</b> signals to the Powerplant, Transmission, Electrical, Brakes and Steering subsystems to control vehicle behavior. 
</p>
<p>
The Driver subsystem boundary is set at the human-vehicle interface.  Hence, the Driver generates only non-electrical signals for use by other subsystems.  These include actuator position settings (e.g. accelerator pedal position) that trigger generation of electrical signals in other subsystems.  The Driver also has direct mechanical interactions with selected subsystems, such as the Steering subsystem through steering angle or steering torque.  Additionally, external signals from the Environment subsystem are also accepted, for use by internal control strategies.
</p>
<p>
For modeling of drive-by-wire systems, the relevant electro-mechanical sensor and actuator models will reside within the appropriate electro-mechanical subsystem rather than within the Driver subsystem.  The following driver device-subsystem associations are assumed by the VMA: 
<ul>
<li>Accelerator pedal sensor and actuator models will reside in the Powerplant subsystem.</li>
<li>Brake pedal sensor and actuator models will reside in the Brakes subsystem.</li>
<li>Steering sensor and actuator models will reside in the Steering subsystem.</li>
</ul>
These assignments are applicable even for advanced vehicle systems that interpret driver commands through a vehicle system controller.  In these cases, driver commands are converted to electrical signals and placed on the Control Bus from within the subsystem where the appropriate sensor model resides.
</p>
</html>
"), Diagram(
      Line(points=[-60, -60; -34, -38; -10, -60; 2, -50]),
      Line(points=[-60, -60; -60, 8; -30, -2]),
      Line(points=[-60, 24; -60, 8]),
      Ellipse(extent=[-74, 52; -44, 24])),
    Icon);
  
end Driver;
