model Driveline "Kinematic front wheel drive configuration" 
  
  parameter Modelica.SIunits.Inertia tire_inertia=1.4;
  extends VehicleSystems.Icons.Driveline;
  extends VehicleSystems.Interfaces.Subsystems.Driveline;
  annotation (Diagram);
  Modelica.Mechanics.Rotational.Inertia left_rear_tire(J=tire_inertia) 
    annotation (extent=[30, -70; 50, -50], rotation=90);
  Modelica.Mechanics.Rotational.Inertia right_rear_tire(J=tire_inertia) 
    annotation (extent=[30, 52; 50, 72], rotation=270);
  Modelica.Mechanics.Rotational.Inertia right_front_tire(J=tire_inertia) 
    annotation (extent=[-50, 52; -30, 72], rotation=270);
  Modelica.Mechanics.Rotational.Inertia left_front_tire(J=tire_inertia) 
    annotation (extent=[-50, -70; -30, -50], rotation=90);
  Modelica.Mechanics.Rotational.IdealPlanetary differential(ratio=1) 
    annotation (extent=[-50, 10; -30, 30], rotation=90);
  Interfaces.FrontAxle front_axle annotation (extent=[-4,-10; 16,10]);
  Interfaces.RearAxle rear_axle annotation (extent=[24,-10; 44,10]);
equation 
  connect(differential.ring, right_front_tire.flange_b) 
    annotation (points=[-40, 30; -40, 52], style(color=0));
  connect(differential.sun, left_front_tire.flange_b) 
    annotation (points=[-40, 10; -40, -50], style(color=0));
  connect(differential.carrier, driveshaft) 
    annotation (points=[-44, 10; -44, 0; -100, 0], style(color=0));
  connect(front_axle.right_front, right_front_tire.flange_a) annotation (points=
       [0,10; 0,80; -40,80; -40,72], style(
      color=0,
      rgbcolor={0,0,0},
      fillColor=7,
      rgbfillColor={255,255,255},
      fillPattern=1));
  connect(front_axle.left_front, left_front_tire.flange_a) annotation (points=[
        0,-10; 0,-80; -40,-80; -40,-70], style(
      color=0,
      rgbcolor={0,0,0},
      fillColor=7,
      rgbfillColor={255,255,255},
      fillPattern=1));
  connect(rear_axle.rear_left, left_rear_tire.flange_b) annotation (points=[40,
        -10; 40,-50], style(
      color=0,
      rgbcolor={0,0,0},
      fillColor=7,
      rgbfillColor={255,255,255},
      fillPattern=1));
  connect(rear_axle.rear_right, right_rear_tire.flange_b) annotation (points=[
        40,10; 40,52], style(
      color=0,
      rgbcolor={0,0,0},
      fillColor=7,
      rgbfillColor={255,255,255},
      fillPattern=1));
  connect(front_axle.wheels,rear_axle. wheels) annotation (points=[0.6,0; 39.6,
        0], style(
      fillColor=7,
      rgbfillColor={255,255,255},
      fillPattern=1));
  connect(rear_axle.wheels, wheels) annotation (points=[39.6,0; 100,0],
            style(
      fillColor=7,
      rgbfillColor={255,255,255},
      fillPattern=1));
end Driveline;
